@@ -59,11 +59,11 @@ value_variables_N <- function(dframe,varlist,
                               verbose= FALSE,
                               parallelCluster=NULL,
                               use_parallel = TRUE,
-                              customCoders = list('c.PiecewiseV.num' = vtreat::solve_piecewise,
+                              customCoders = list('c.PiecewiseV.num' = vtreat::solve_piecewisec,
                                                   'n.PiecewiseV.num' = vtreat::solve_piecewise,
-                                                  'c.knearest.num' = vtreat::square_window,
+                                                  'c.knearest.num' = vtreat::square_windowc,
                                                   'n.knearest.num' = vtreat::square_window,
-                                                  'c.spline.num' = vtreat::spline_variable,
+                                                  'c.spline.num' = vtreat::spline_variablec,
                                                   'n.spline.num' = vtreat::spline_variable),
                               codeRestriction = c("PiecewiseV", 
                                                   "knearest",
@@ -131,15 +131,15 @@ value_variables_C <- function(dframe,varlist,
                               scale=FALSE,doCollar=FALSE,
                               splitFunction=NULL,ncross=3,
                               forceSplit = FALSE,
-                              catScaling=FALSE,
+                              catScaling = TRUE,
                               verbose= FALSE,
                               parallelCluster=NULL,
                               use_parallel = TRUE,
-                              customCoders = list('c.PiecewiseV.num' = vtreat::solve_piecewise,
+                              customCoders = list('c.PiecewiseV.num' = vtreat::solve_piecewisec,
                                                   'n.PiecewiseV.num' = vtreat::solve_piecewise,
-                                                  'c.knearest.num' = vtreat::square_window,
+                                                  'c.knearest.num' = vtreat::square_windowc,
                                                   'n.knearest.num' = vtreat::square_window,
-                                                  'c.spline.num' = vtreat::spline_variable,
+                                                  'c.spline.num' = vtreat::spline_variablec,
                                                   'n.spline.num' = vtreat::spline_variable),
                               codeRestriction = c("PiecewiseV", 
                                                   "knearest",
